// `Tracer` trait
mod tracer;
pub use tracer::Tracer;

pub mod tracing_macros {
    pub use tracing::{trace_span, info_span, debug_span, warn_span, error_span};
}

// trace object implements the `Tracer` trait
#[macro_use]
mod trace;
pub use trace::Trace;

pub const EMPTY_FIELD: tracing::field::Empty = tracing::field::Empty;

// re-export the filter object
pub use tracing_subscriber::EnvFilter;
// re-export the subscriber extensions so `collector.init()` can be called explicitly
pub use tracing_subscriber::util::SubscriberInitExt;
pub use tracing::Span;

// export the trace listener utils
mod utils;
pub use utils::{create_trace_listener, TraceListenerOptions};

// log writers
mod writers;
pub use writers::{NoopWriter, FileWriter};

// reexport the type with better name
use tracing::Level;
pub type TraceLevel = Level;
